# prestige_irc

This module is a simple API for IRC networks.

Note that this project is `python 3.6` or higher, since it uses fstrings.

# Installation

## pip

`pip install prestige_irc`

or

`python -m pip install prestige_irc`

## Manually

Clone this repository into your repo, and install `setup.py`:

```python
git clone https://github.com/avahe-kellenberger/prestige_irc.git
cd prestige_irc
python setup.py install
```
You should now be able to import modules, e.g. `from prestige_irc.commands import Commands`

# Documentation

[View the documentation.](https://github.com/avahe-kellenberger/prestige_irc/wiki/Documentation-Home)
  
# Speculative Updates:
In the future, this module may support every RFC specified IRC command, if it becomes widely requested.
 
